[Buildbot-commits] buildbot/buildbot/process builder.py,1.47,1.48

Brian Warner warner at users.sourceforge.net
Tue Aug 7 19:21:42 UTC 2007


Update of /cvsroot/buildbot/buildbot/buildbot/process
In directory sc8-pr-cvs3.sourceforge.net:/tmp/cvs-serv17293/buildbot/process

Modified Files:
	builder.py 
Log Message:
[project @ move BuildSlave to new class, merge with BotPerspective, make it long-lived]

Original author: warner at lothar.com
Date: 2007-08-07 19:18:50+00:00

Index: builder.py
===================================================================
RCS file: /cvsroot/buildbot/buildbot/buildbot/process/builder.py,v
retrieving revision 1.47
retrieving revision 1.48
diff -u -d -r1.47 -r1.48
--- builder.py	1 Aug 2007 20:31:49 -0000	1.47
+++ builder.py	7 Aug 2007 19:21:40 -0000	1.48
@@ -158,7 +158,7 @@
 
     def _ping_timeout(self, remote):
         log.msg("ping timeout")
         # force the BotPerspective to disconnect, since this indicates that
         # the bot is unreachable.
         del self.timer
         remote.broker.transport.loseConnection()
@@ -401,12 +401,11 @@
             reactor.callLater(0, w.callback, fire_with)
 
     def attached(self, slave, remote, commands):
         """This is invoked by the BotPerspective when the self.slavename bot
         registers their builder.
 
-        @type  slave: L{buildbot.master.BotPerspective}
-        @param slave: the BotPerspective that represents the buildslave as a
-                      whole
+        @type  slave: L{buildbot.master.BuildSlave}
+        @param slave: the BuildSlave that represents the buildslave as a whole
         @type  remote: L{twisted.spread.pb.RemoteReference}
         @param remote: a reference to the L{buildbot.slave.bot.SlaveBuilder}
         @type  commands: dict: string -> string, or None
@@ -158,7 +158,7 @@
     def _ping_timeout(self, remote):
         log.msg("ping timeout")
-        # force the BotPerspective to disconnect, since this indicates that
+        # force the BuildSlave to disconnect, since this indicates that
         # the bot is unreachable.
         del self.timer
@@ -401,12 +401,11 @@
 
     def attached(self, slave, remote, commands):
-        """This is invoked by the BotPerspective when the self.slavename bot
+        """This is invoked by the BuildSlave when the self.slavename bot
         registers their builder.
 





More information about the Commits mailing list